@@ -7,4 +7,4 @@ fi
 
 case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
 /usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
-/usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/XWin.exe -n "Cygwin-X${wow64}/MATE" -a "--quote /usr/bin/bash.exe -l -c \"cd; /usr/bin/startx /etc/X11/xinit/Xsession mate\"" /usr/bin/run.exe
+/usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/XWin.exe -n "Cygwin-X${wow64}/MATE" -a "--quote /usr/bin/bash.exe -l -c \"cd; exec /usr/bin/startx /etc/X11/xinit/Xsession mate\"" /usr/bin/run.exe
